###### Variables #####
######################

## Cell Config ##
#################
cell_type=Linux
pid=$(service vmware-vcd pid cell)
cell_name=$(hostname | cut -d. -f1)
cell_role=$(cat /opt/vmware/vcloud-director/appliance-type)
current_primary=$(cat /opt/vmware/vcloud-director/current-primary-ip-address)
version=$(grep product.version /opt/vmware/vcloud-director/etc/global.properties | cut -d= -f2)
int_eth0=`grep vcloud.cell.ips /opt/vmware/vcloud-director/etc/global.properties | cut -d, -f1 | cut -d[ -f2`
int_eth1=`grep vcloud.cell.ips /opt/vmware/vcloud-director/etc/global.properties | cut -d, -f2`
up_time=$(uptime)

#*** NEW**
cell_start=$(grep "Application startup begins: Subsystem 'Legacy Cell Application'" /opt/vmware/vcloud-director/logs/cell.log | awk '{print $9,$10}')
watch_start=$(grep "vmware-vcd-watchdog started" /opt/vmware/vcloud-director/logs/vmware-vcd-watchdog.log | awk '{print $1,$2}')

cell_start_last=$(grep "Application startup begins: Subsystem 'Legacy Cell Application'" /opt/vmware/vcloud-director/logs/cell.log.last | awk '{print $9,$10}')
watch_start_last=$(grep "vmware-vcd-watchdog started" /opt/vmware/vcloud-director/logs/vmware-vcd-watchdog.log.last | awk '{print $1,$2}')
#*** NEW**

## Resource and Sizing #
########################
current=$(pwd)
pg_dir=/opt/vmware/vpostgres/10/bin/

mem_total=$(cat /proc/meminfo | grep MemTotal | cut -dk -f1 | awk '{print int($2/1024000)}')
cpu_count=$(cat /proc/cpuinfo | grep -c processor)
cpu_speed=$(cat /proc/cpuinfo | grep "model name" | cut -d@ -f2 | sort -n | awk 'FNR > 1')
java_heap=$(egrep 'Xmx' /opt/vmware/vcloud-director/bin/*common | awk '{print $2}'| cut -dx -f2)

cd $pg_dir
cells=$(sudo -u postgres psql vcloud -t -c "select count(*) from cells;"| sed 's/^[ \t]*//')
vcs=$(sudo -u postgres psql vcloud -t -c "select count(*) from virtual_center;"| sed 's/^[ \t]*//')
esxi=$(sudo -u postgres psql vcloud -t -c "select count(*) from managed_server;"| sed 's/^[ \t]*//')
nsxv=$(sudo -u postgres psql vcloud -t -c "select count(*) from vshield_manager;"| sed 's/^[ \t]*//')
nsxt=$(sudo -u postgres psql vcloud -t -c "select count(*) from nsxt_manager;"| sed 's/^[ \t]*//')
datastores=$(sudo -u postgres psql vcloud -t -c "select count(*) from datastore;"| sed 's/^[ \t]*//')

ext_nets=$(sudo -u postgres psql vcloud -t -c "select count(*) from logical_network where scope_type='1';"| sed 's/^[ \t]*//')
orgs=$(sudo -u postgres psql vcloud -t -c "select count(*) from organization;"| sed 's/^[ \t]*//')
vdcs=$(sudo -u postgres psql vcloud -t -c "select count(*) from org_prov_vdc;"| sed 's/^[ \t]*//')
vapps=$(sudo -u postgres psql vcloud -t -c "select count(*) from vm_container;"| sed 's/^[ \t]*//')
cd $current


## Tuning ##
############

db_url=$(grep database.jdbcUrl /opt/vmware/vcloud-director/etc/global.properties | cut -d= -f 2,3)
app_tune=$(egrep 'database.pool|Threads' /opt/vmware/vcloud-director/etc/global.properties)
pg_tune=$(egrep 'max_connections|shared_buffers|effective_cache_size|track_counts|autovacuum|idle_in' /var/vmware/vpostgres/10/pgdata/postgresql.conf)


## Process and Service Config ##
################################

#vcd_threads=$(ps -L -u vcloud | wc -l)
#vcd_proc_lim=`cat /proc/$pid/limits | grep processes | awk '{print $3,$4}'`
#userprocess=$(ulimit -a | grep processes | awk '{print $5}')

maxFiles=$(grep files /proc/$(service vmware-vcd pid cell)/limits | awk '{print $4,$5,$6}')
maxFileDescriptors=$(grep VCLOUD_MAX_FD /etc/profile.d/vcloud.sh | awk '{print $2}')
openFileDescriptorsCloud=$(lsof -a -p $(service vmware-vcd pid cell) | wc -l)
open_cd_breakdown=$(lsof -a -p $(service vmware-vcd pid cell) | awk '{print $5}' |sort| uniq -c |sort -nr)

openFileDescriptorsAll=$(ls -lth /proc/*/fd/ | wc -l)
fdSoftLimit=$(ulimit -n -S)
fdHardLimit=$(ulimit -n -H)


## Disk and Transfer ##
#######################


disk=$(df -h| sed 's/^[ \t]*//')
nfs=$(cat /etc/fstab | grep transfer)
data_perm=$(stat -c '%A %a %n' /opt/vmware/vcloud-director/data)
transfer_perm=$(stat -c '%A %a %n' /opt/vmware/vcloud-director/data/transfer)
nodes="ls /opt/vmware/vcloud-director/data/transfer/appliance-nodes/"
node_count=$(ls /opt/vmware/vcloud-director/data/transfer/appliance-nodes/ | wc -l)

defaultBrokerfiles=$(ls /opt/vmware/vcloud-director/data/activemq/defaultBroker/ | egrep -v 'bindings|amq' | wc -l)
broker_size=$(du -Sh /opt/vmware/vcloud-director/data/activemq/defaultBroker/)
file_breakdown=$(ls -lth /opt/vmware/vcloud-director/data/activemq/defaultBroker/ | awk '{print $9}' | cut -d. -f2 | sort | uniq -c | sort -nr)


## Network and DNS Config ##
#############################

#eth0=$(ip a show dev eth0 | egrep 'link|inet' | awk '{print $2}' | sort -r | sed 's/^[ \t]*//')
eth0=$(ip a show dev eth0 | egrep 'inet' | awk '{print $2}' | sort -r | sed 's/^[ \t]*//' | cut -d/ -f 1)
eth1=$(ip a show dev eth1 | egrep 'link|inet' | awk '{print $2}' | sort -r | sed 's/^[ \t]*//')
hostfile=$(cat /etc/hosts | egrep -v '::1|#|localhost')
dnsserver=$(grep nameserver /etc/resolv.conf)
routes=$(route -n | awk 'FNR > 2 {print $2,"via",$8}' | grep -v "0.0.0.0")
arpcache=$(arp -a | sed 's/^[ \t]*//')


## NTP ##
#########

timedate=$(timedatectl | egrep 'Local time|Network time on|NTP synchronized' | sed 's/^[ \t]*//')
ntpservice=$(systemctl status ntpd | sed 's/^[ \t]*//')

##  vCloud Logging Config ##
############################

logconfig=$(egrep 'File=logs|MaxFileSize|MaxBackupIndex|threshold|#|^$'  /opt/vmware/vcloud-director/etc/log4j.properties)


## Ports ##
###########
openports=$(netstat -nalp | grep "LISTEN " | egrep '22|80|443|5432|8443|61616|8999')
connections=$(netstat -nalp | grep "ESTAB" | egrep '5432|61616')

amqp=$(netstat -tanp | grep ESTABLISHED | awk '{print $5}' | grep 61616 | sort | uniq)
sockets=$(netstat -an | grep ESTABLISHED | wc -l)
sockets_breakdown=$(netstat -np | grep ESTABLISHED | awk '{print $7}' | cut -d/ -f2 | sort | uniq -c |sort -nr)

#########################################################################################
#########################################################################################

echo " " > $HOSTNAME.txt
echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m    Current Cell Configuration    \033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt
printf "%b" "\e[1;33mVersion:\e[0m $version \n"  >> $HOSTNAME.txt
if [[ `cat /etc/issue | awk 'FNR < 2'` =~ "VA" ]]
then
        cell_type=Appliance
else
        cell_type=Linux
fi
printf "%b" "\e[1;33mCell Type:\e[0m $cell_type \n" >> $HOSTNAME.txt 
echo  >> $HOSTNAME.txt
printf "%b" "\e[1;33mHostname:\e[0m $cell_name \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33m    eth0:\e[0m $int_eth0 \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33m    eth1:\e[0m $int_eth1 \n" >> $HOSTNAME.txt
echo >> $HOSTNAME.txt
printf "%b" "\e[1;33mCurrent Role:\e[0m $cell_role\n" >> $HOSTNAME.txt
if [[ $cell_role != "primary" ]]
then
	printf "%b" "\e[1;33mFollowing:\e[0m $current_primary \n" >> $HOSTNAME.txt
fi
printf "%b" "\e[1;33mCurrent Time and Uptime:\e[0m$up_time \n" >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt

printf "%b" "\e[1;33mMost Recent Service Start:\e[0m  Cell.log:$cell_start, Watchdog.log:$watch_start  \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mSystemctl:\e[0m $(systemctl status vmware-vcd | grep active)\n"  >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt

printf "%b" "\e[1;33mService Start Prior:\e[0m  Cell.log:$cell_start_last, Watchdog.log:$watch_start_last  \n" >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt

echo -e "\033[1;32m========================================\033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m         Resources and Sizing Config           \033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m========================================\033[m" >> $HOSTNAME.txt

printf "%b" "\e[1;34mConfigured Resources\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mMem:\e[0m $mem_total \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mCPU:\e[0m $cpu_count @$cpu_speed \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mJava Heap:\e[0m $java_heap \n\n" >> $HOSTNAME.txt

##T-Shirt Size Calc

    if [[ $mem_total -ge "32" ]] ; then
    memsize="VMware Validated Design"

    elif [[ $mem_total -ge "24" ]] ; then
    memsize="Large"

    elif [[ $mem_total -ge "12" ]] ; then
    memsize="Small"

    elif [[ $mem_total -ge "8" ]] ; then
    memsize="Application"

    fi


    if [[ $cpu_count -ge "24" ]] ; then
    cpusize="VMware Validated Design"

    elif [[ $cpu_count -ge "8" ]] ; then
    cpusize="Large 10.2.1"

    elif [[ $cpu_count -ge "4" ]] ; then
    cpusize="Legacy Large/Application 10.2.1"

    elif [[ $cpu_count -ge "2" ]] ; then
    cpusize="Small/Legacy Application"

    fi





printf "%b" "\e[1;34mT-Shirt Size\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mMem Size:\e[0m $memsize \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mCPU Size:\e[0m $cpusize \n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;36m****************************\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;36mReference Sizes as of 10.2.1\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;36m****************************\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;35mVmware Validated Design:\e[0m 32GB 24vCPU \n" >> $HOSTNAME.txt
printf "%b" "\e[1;35mLarge:\e[0m                   24GB  8vCPU \n" >> $HOSTNAME.txt
printf "%b" "\e[1;35mLegacy Large:\e[0m            24GB  4vCPU \n" >> $HOSTNAME.txt
printf "%b" "\e[1;35mSmall:\e[0m                   12GB  2vCPU \n" >> $HOSTNAME.txt
printf "%b" "\e[1;35mApplication:\e[0m              8GB  4vCPU \n" >> $HOSTNAME.txt
printf "%b" "\e[1;35mLegacy Application:\e[0m       8GB  2vCPU \n\n" >> $HOSTNAME.txt

# DB Objects

printf "%b" "\e[1;34mDatabase Objects\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mCells:\e[0m                 $cells \n\n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mvCenters:\e[0m              $vcs \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mESXis:\e[0m                 $esxi \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mNSXv:\e[0m                  $nsxv \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mNSXt:\e[0m                  $nsxt \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mDatastores:\e[0m            $datastores \n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mExternal Networks:\e[0m     $ext_nets \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mOrganizations/Tenants:\e[0m $orgs \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mOrg vDCs:\e[0m              $vdcs \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mvApps:\e[0m                 $vapps \n\n" >> $HOSTNAME.txt




echo -e "\033[1;32m==============================================\033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m         Database and Application Tuning           \033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m==============================================\033[m" >> $HOSTNAME.txt

echo " " >> $HOSTNAME.txt
printf "%b" "\e[1;34m1. DB Connection String\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33m$db_url \n">> $HOSTNAME.txt

if [[ `grep database.jdbcUrl /opt/vmware/vcloud-director/etc/global.properties` =~ "90" ]]; then
        printf "%b" "\e[1;35m90 is the default timeout, please increase to 900 when performing an upgrade \n">> $HOSTNAME.txt
fi

echo " " >> $HOSTNAME.txt
printf "%b" "\e[1;34m2. Additional Global.properties Parameters\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33m--/opt/vmware/vcloud-director/etc/global.properties\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;35m$app_tune \n">> $HOSTNAME.txt

echo " " >> $HOSTNAME.txt
printf "%b" "\e[1;34m3. PostgreSQL Tuning\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33m--/var/vmware/vpostgres/10/pgdata/postgresql.conf\e[0m \n" >> $HOSTNAME.txt
printf "%b" "\e[1;35m$pg_tune\e[0m \n\n" >> $HOSTNAME.txt


echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m         Process Config           \033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt

echo " " >> $HOSTNAME.txt
#printf "%b" "\e[1;33mvCD Threads:\e[0m $vcd_threads \n" >> $HOSTNAME.txt
#printf "%b" "\e[1;33mvCloud Process Limits:\e[0m $vcd_proc_limit \n" >> $HOSTNAME.txt
#printf "%b" "\e[1;33mUser Process Limits:\e[0m $userprocess \n\n" >> $HOSTNAME.txt


printf "%b" "\e[1;33mProcess File Limit:\e[0m $maxFiles\n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mProcess File Config:\e[0m $maxFileDescriptors\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mOpen File Descriptors - All:\e[0m $openFileDescriptorsAll\n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mOpen File Descriptors - Cloud:\e[0m $openFileDescriptorsCloud\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mCloud FD Breakdown:\e[0m\n$open_cd_breakdown\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mOS Soft Limit:\e[0m $fdSoftLimit\n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mOS Hard Limit:\e[0m $fdHardLimit\n\n" >> $HOSTNAME.txt



printf "%b" "\e[1;35mabove Process Limits should be the same unless set via /etc/security/limits.conf  \n\n" >> $HOSTNAME.txt

echo -e "\033[1;32m========================================================\033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m            Transfer Directory and Disk Usage           \033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m========================================================\033[m" >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt

printf "%b" "\e[1;33mDisk Usage:\e[0m\n$disk \n\n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mTransfer fstab:\e[0m\n$nfs \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mPermissions on Data:\e[0m\n$data_perm \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mPermissions on Transfer:\e[0m\n$transfer_perm \n\n" >> $HOSTNAME.txt


if [[ $node_count != $cells ]] ; then
  printf "%b" "\e[1;41mThe number of Nodes directories and Cells do not match\e[0m\n"
  printf "%b" "\e[1;33mvCD Cells:\e[0m $cells \n" >> $HOSTNAME.txt
  printf "%b" "\e[1;33mvCD Nodes:\e[0m $node_count \n" >> $HOSTNAME.txt

else
  printf "%b" "\e[1;33mNode Directories:\e[0m $node_count \n" >> $HOSTNAME.txt
fi

printf "%b" "\e[1;33mCurrent Node:\e[0m$HOSTNAME - $eth0\n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mKnown Nodes:\n" >> $HOSTNAME.txt

#printf "%b" "\e[1;35TESTING\n" >> $HOSTNAME.txt
#printf "$nodes" >> $HOSTNAME.txt

$nodes |

while read -r line
do

nodename=$(cat /opt/vmware/vcloud-director/data/transfer/appliance-nodes/$line/repmgr-node-name)
nodeip=$(cat /opt/vmware/vcloud-director/data/transfer/appliance-nodes/$line/ip-eth0)

printf "%b" "\e[1;35m -$nodename $nodeip \n" >> $HOSTNAME.txt

done

printf "%b" "\e[1;33m\nCurrent Size of Broker Directory:\e[0m\n$broker_size\n\n" >> $HOSTNAME.txt
printf "%b" "\e[1;33m$file_breakdown\n" >> $HOSTNAME.txt
printf "%b" "\e[1;33m\nNumber of non binding or amq files:\e[0m $defaultBrokerfiles\n\n" >> $HOSTNAME.txt



echo " " >> $HOSTNAME.txt
echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m      Network and DNS Config           \033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt

printf "%b" "\e[1;33mEth0:\e[0m\n$eth0 \n" >> $HOSTNAME.txt
printf "%b" "\e[1;33mEth1:\e[0m\n$eth1 \n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mCurrent /etc/hosts entries:\e[0m$hostfile \n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mDNS:\e[0m\n$dnsserver \n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mGateway:\e[0m\n$routes \n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mArp Cache:\e[0m\n$arpcache \n\n" >> $HOSTNAME.txt

echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m          NTP Config           \033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt

printf "%b" "\e[1;33mCurrent Time Settings:\e[0m\n$timedate \n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mNTP Service:\e[0m\n$ntpservice \n\n" >> $HOSTNAME.txt

echo " " >> $HOSTNAME.txt


echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m vCloud Logging      \033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt
printf "%b" "\e[36m$logconfig\e[0m \n\n" >> $HOSTNAME.txt

echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m Listening and Established Ports       \033[m" >> $HOSTNAME.txt
echo -e "\033[1;32m==================================\033[m" >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt


printf "%b" "\e[1;33mOpen Ports:\e[0m\n$openports \n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33mEstablished Connections:\e[0m\n$connections \n\n" >> $HOSTNAME.txt

printf "%b" "\e[1;33m\nExisting AMQP Connections:\e[0m\n$amqp\n" >> $HOSTNAME.txt


printf "%b" "\e[1;33m\nNumber of existing ESTABLISHED connections:\e[0m $sockets\n" >> $HOSTNAME.txt
printf "%b" "\e[1;33m$sockets_breakdown\n" >> $HOSTNAME.txt


echo " " >> $HOSTNAME.txt
printf "%b" "\e[1;37mFor Port information see\e[0m\n" >> $HOSTNAME.txt
printf "%b" "\e[1;36mhttps://docs.vmware.com/en/VMware-Cloud-Director/10.2/vcd_102_install.pdf\e[0m\n " >> $HOSTNAME.txt
echo " " >> $HOSTNAME.txt

