## Definitions
##############

PATH=/usr/sbin:${PATH}

logfile="$(hostname -s).artemis.log.$(date +'%F_%H_%Z')"
log_dir="/opt/vmware/vcloud-director/data/transfer/artemis/"
log=$log_dir$logfile

cloudversion=$(grep product.version /opt/vmware/vcloud-director/etc/global.properties | cut -d= -f2)
build=$(grep BUILD /etc/vmware/.buildInfo | cut -d" " -f2)
mem_total=$(cat /proc/meminfo | grep MemTotal | cut -dk -f1 | awk '{print int($2/1024000)}')
cpu_count=$(cat /proc/cpuinfo | grep -c processor)
cpu_speed=$(cat /proc/cpuinfo | grep "model name" | cut -d@ -f2 | sort -n | awk 'FNR > 1')
eth0=$(ip a show dev eth0 | egrep 'inet' | awk '{print $2}' | sort -r | sed 's/^[ \t]*//' | cut -d/ -f 1)
hostname=$(hostname)


numnodes=$(ls -ld /opt/vmware/vcloud-director/data/transfer/appliance-nodes/node* | wc -l)
cells=$(sudo -i -u postgres psql vcloud -t -c "select name,primary_ip from cells where is_active = 't';" | sed 's/^[ \t]*//;/^$/d;s#^https://##')
numcells=$(sudo -i -u postgres psql vcloud -t -c "select count(*) from cells;" | sed 's/^[ \t]*//;/^$/d;s#^https://##')
activecells=$(sudo -i -u postgres psql vcloud -t -c "select count(*) from cells where is_active = 't';" | sed 's/^[ \t]*//;/^$/d;s#^https://##')

def_vcd_recent_members=$(grep members  /opt/vmware/vcloud-director/logs/cell-runtime.log | tail -n2 | awk '{print $1,$2}')
vcd_members=$(less /opt/vmware/vcloud-director/logs/cell-runtime.log | grep -A 5 vcd-cluster=topology | tail -n5 | egrep 'TopologyMember' | awk '{print $3,$4,$5,$8,$11}')
default_members=$(less /opt/vmware/vcloud-director/logs/cell-runtime.log | grep -A 5 defaultTopology=topology | tail -n5 | egrep 'TopologyMember' | awk '{print $3,$4,$5,$8,$11}')

maxFiles=$(grep files /proc/$(service vmware-vcd pid cell)/limits | awk '{print $4,$5,$6}')
maxFileDescriptors=$(grep VCLOUD_MAX_FD /etc/profile.d/vcloud.sh | awk '{print $2}')
openFileDescriptorsCloud=$(lsof -a -p $(service vmware-vcd pid cell) | wc -l)
open_cd_breakdown=$(lsof -a -p $(service vmware-vcd pid cell) | awk '{print $5}' |sort| uniq -c |sort -nr)

openFileDescriptorsAll=$(ls -lth /proc/*/fd/ | wc -l)
fdSoftLimit=$(ulimit -n -S)
fdHardLimit=$(ulimit -n -H)

defaultBrokerfiles=$(ls /opt/vmware/vcloud-director/data/activemq/defaultBroker/ | egrep -v 'bindings|amq' | wc -l)
broker_size=$(du -Sh /opt/vmware/vcloud-director/data/activemq/defaultBroker/)
file_breakdown=$(ls -lth /opt/vmware/vcloud-director/data/activemq/defaultBroker/ | awk '{print $9}' | cut -d. -f2 | sort | uniq -c | sort -nr)


amqp=$(netstat -tanp | grep ESTABLISHED | awk '{print $5}' | grep 61616 | sort | uniq)
sockets=$(netstat -an | grep ESTABLISHED | wc -l)
sockets_breakdown=$(netstat -np | grep ESTABLISHED | awk '{print $7}' | cut -d/ -f2 | sort | uniq -c |sort -nr)

nodes="ls /opt/vmware/vcloud-director/data/transfer/appliance-nodes/"


## Main
########

printf "%b" "\e[1;34m==================Current Cell Configuration==================\e[0m \n\n" > $log
printf "Version: $cloudversion\n" >> $log
printf "Mem: $mem_total \n" >> $log
printf "CPU: $cpu_count @$cpu_speed \n" >> $log
printf "IP: $eth0 \n" >> $log

if [[ $build<"19610595"* ]] ; then
printf "%b" "\e[1;35m===>>> Cloud Version less than 10.3.3, consider upgrading to patch Artemis issues\e[0m \n\n"  >> $log

elif [[ $build>="19610595"* ]] ; then
printf "%b" "\e[1;35m===>>> Cloud Version less is at least 10.3.3\e[0m \n\n"  >> $log

fi


printf "%b" "\e[1;34m==================Current File Descriptor Configuration==================\e[0m \n\n" >> $log
printf "Process File Limit: $maxFiles\n" >> $log
printf "Process File Config: $maxFileDescriptors\n" >> $log

printf "Open File Descriptors - All: $openFileDescriptorsAll\n" >> $log
printf "Open File Descriptors - Cloud: $openFileDescriptorsCloud\n" >> $log

printf "Cloud FD Breakdown:\n $open_cd_breakdown\n" >> $log

printf "OS Soft Limit: $fdSoftLimit\n" >> $log
printf "OS Hard Limit: $fdHardLimit\n\n" >> $log


printf "%b" "\e[1;34m==================Disk Space and File Usage==================\e[0m \n\n" >> $log
df -h >> $log

printf "\nCurrent Size of Broker Directory: $broker_size\n" >> $log
printf "$file_breakdown\n" >> $log
printf "\nNumber of non binding or amq files: $defaultBrokerfiles\n\n" >> $log


printf "%b" "\e[1;34m==================Nodes and Ports==================\e[0m \n\n" >> $log
printf "Current Node: $hostname - $eth0\n\n" >> $log

printf "Number of Nodes: $numnodes\n" >> $log
printf "Number of Cells: $numcells\n" >> $log
printf "Number of Active Cells: $activecells\n" >> $log

printf "\nActive Cells:\n$cells\n" >> $log

printf "\nKnown Nodes:\n" >> $log
$nodes |

while read -r line
do

nodetype=$(cat /opt/vmware/vcloud-director/data/transfer/appliance-nodes/$line/appliance-type)
nodename=$(cat /opt/vmware/vcloud-director/data/transfer/appliance-nodes/$line/repmgr-node-name)
nodeip=$(cat /opt/vmware/vcloud-director/data/transfer/appliance-nodes/$line/ip-eth0)

                printf " - $nodename $nodeip $nodetype \n" >> $log

done

printf "\nDefault Topology and VCD Topology Members:\n$def_vcd_recent_members\n" >> $log
printf "\nDefault Members:\n$default_members\n"  >> $log
printf "\nVCD Members:\n$vcd_members\n"  >> $log


printf "\nExisting AMQP Connections:\n$amqp\n" >> $log

printf "\nNumber of existing ESTABLISHED connections: $sockets\n" >> $log
printf "$sockets_breakdown\n" >> $log


